@@ -16,31 +16,6 @@ TTL_1YEAR = 31556926
 # TTL_1MINUTE = 60
 
 
-def create_bucket(bucket_name: str, region: str, dry_run: bool = False) -> bool:
-    # Create the bucket
-    client = boto3.client('s3')
-    try:
-        if not dry_run:
-            response = client.create_bucket(
-                ACL='private',
-                CreateBucketConfiguration={
-                    'LocationConstraint': region
-                },
-                Bucket=bucket_name,
-            )
-            log.debug(f'Waiting for bucket ({bucket_name}) to be created...')
-            waiter = client.get_waiter('bucket_exists')
-            waiter.wait(Bucket=bucket_name)
-            log.debug(f'Bucket ({bucket_name}) creation completed')
-    except client.meta.client.exceptions.BucketAlreadyExists as e:
-        logging.error(e)
-        return False
-    except client.meta.client.exceptions.BucketAlreadyOwnedByYou as e:
-        logging.error(e)
-        return False
-    return True
-
-
 # Original source: https://stackoverflow.com/a/3431838/298054
 def hash_file(file: IOBase) -> str:
     hash_impl = hashlib.md5()
